@@ -30,8 +30,12 @@ exception Not_supported
 (** Parsing of an Emacs-style regular expression *)
 val re : ?case:bool -> string -> Core.t
 
+val re_result : ?case:bool -> string -> (Core.t, [ `Not_supported | `Parse_error ]) result
+
 (** Regular expression compilation *)
 val compile : Core.t -> Core.re
 
 (** Same as [Core.compile] *)
 val compile_pat : ?case:bool -> string -> Core.re
+
+val re_no_emacs : case:bool -> string -> Core.t
